use std::sync::mpsc;
use super::Bus;

#[derive(Clone, Copy)]
pub enum Mode {
    Transmitter,
    Transceiver,
}

#[derive(Clone, Copy)]
pub struct Packet<T> where T:Clone {
    pub from:u32,
    pub to:u32,
    pub data:T,
}
impl<T:Clone> Packet<T> {
    pub fn new(from:u32, to:u32, data:T) -> Self
    {
        Self {
            from:from,
            to:to,
            data:data,
        }
    }
}

pub enum Query {
    Notify,
    List,
    Connect(Mode),
    Signal(Option<mpsc::Sender<()>>),
    SetPort(u32),
    GetPort(u32),
}

pub enum Response<T> where T: 'static + Clone + Send {
    Ok,
    Error,
    List(Vec<usize>),
    Connect(Bus<T>),
    GetPort(Option<u32>),
}

pub struct QueryPacket {
    pub from:u32,
    pub data:Query,
}
impl QueryPacket {
    pub fn new(from:u32, data:Query) -> Self
    {
        Self {
            from:from,
            data:data,
        }
    }
}
